# BMI_Calculator

Description.
This package calculates the body mass index.
    It takes two inputs:
        - Height(in meters)
        - Weight (in kg)
    and returns an interpretation based on the BMI value
        - Under 18.5: underweight
        - Over 18.5 but below 25: normal weight
        - Over 25 but below 30: slightly overweight
        - Over 30 but below 35: obese
        - Above 35: clinically obese.

## Installation
use the package manager [pip](https://pip.pypa.io/en/stable) to install this package

'''bash
pip install my_first_package_bmi_calculator
'''

## Author
Wiliam
        